from ..generate.config import GeneratorConfig as GeneratorConfig
from ..generate.template_builder import TemplateBuilder as TemplateBuilder
from ..logger.logging_ import logging as logging
from _typeshed import Incomplete

class GeneratorService:
    config: Incomplete
    builder: Incomplete
    def __init__(self, config: GeneratorConfig) -> None: ...
    def generator_all(self) -> None: ...
    def generator_schema(self, schema_name) -> None: ...
    def generator_table(self, table_name, schema_name) -> None: ...
    def generator_view(self, view_name, schema_name) -> None: ...
