from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging
from sqlalchemy.engine import Engine as Engine
from sqlalchemy.ext.asyncio import AsyncEngine as AsyncEngine

class DatabaseEngine:
    def __new__(cls, name: str = None, async_engine: bool = True): ...
    def get_async_engine(self, name) -> AsyncEngine: ...
    def support_schema(self, name: str) -> bool: ...
    def get_engine(self, name) -> Engine: ...
    def close(self) -> None: ...
    async def async_close(self) -> None: ...
    def __del__(self) -> None: ...
