from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging

class RedisEngine:
    def __new__(cls): ...
    def get_connection(self, pool_name): ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...
