from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging
from ..utils.core_utils import CoreUtil as CoreUtil
from pathlib import Path

class DiskEngine:
    def __new__(cls): ...
    def get_path(self, name: str, child_path: str = '') -> Path: ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...
