from enum import IntEnum

class LabelEnum(IntEnum):
    def __new__(cls, value: int, label: str, description: str = ''): ...
    @classmethod
    def from_label(cls, label: str): ...
    @classmethod
    def labels(cls) -> list[str]: ...
    @property
    def label(self) -> str: ...
    @property
    def description(self) -> str: ...
