class RunningConfig:
    @classmethod
    def get_sqlmodel_schema(cls, schema_name): ...
    @classmethod
    def get_controller_schema(cls, schema_name): ...
    @classmethod
    def get_engine_name(cls, engine_name, schema_name): ...
