from ..engine.database_engine import DatabaseEngine as DatabaseEngine
from _typeshed import Incomplete
from collections.abc import Generator

class DBEngineService:
    @classmethod
    def get_async_engine(cls, database_config_name): ...
    @classmethod
    def get_engine(cls, database_config_name): ...
    @classmethod
    async def get_async_session(cls, database_config_name: str): ...
    @classmethod
    def get_auth_async_engine(cls): ...
    @classmethod
    def get_auth_engine(cls): ...
    @classmethod
    async def get_auth_async_session(cls) -> Generator[Incomplete]: ...
