from functools import cache
from pathlib import Path

class CoreUtil:
    @staticmethod
    def dict_to_bytes(source: dict) -> bytes: ...
    @staticmethod
    def dict_to_str(source: dict) -> str: ...
    @classmethod
    def bytes_to_dict(cls, source: bytes): ...
    @staticmethod
    def str_to_dict(source: str) -> dict: ...
    @classmethod
    @cache
    def get_root_path(cls) -> Path: ...
    @classmethod
    def get_path(cls, path: str | Path) -> Path: ...
    @classmethod
    def get_config_path(cls) -> Path: ...
    @classmethod
    def get_web_path(cls) -> Path: ...
    @classmethod
    def get_admin_path(cls) -> Path: ...
    @staticmethod
    def remove_path(file_or_path: str | Path | None) -> None: ...
